package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.DERUTCTime;
import java.io.IOException;
import java.util.Enumeration;
import java.util.Vector;

public class V2TBSCertListGenerator {
   DERInteger version;
   AlgorithmIdentifier signature;
   X509Name issuer;
   Time thisUpdate;
   Time nextUpdate;
   X509Extensions extensions;
   private Vector crlentries;

   public V2TBSCertListGenerator() {
      V2TBSCertListGenerator var10000 = this;
      V2TBSCertListGenerator var10001 = this;
      V2TBSCertListGenerator var10002 = this;
      V2TBSCertListGenerator var10003 = this;
      super();
      DERInteger var1;
      var1 = new DERInteger.<init>(1);
      var10003.version = var1;
      var10002.nextUpdate = null;
      var10001.extensions = null;
      var10000.crlentries = null;
   }

   public void setSignature(AlgorithmIdentifier signature) {
      this.signature = signature;
   }

   public void setIssuer(X509Name issuer) {
      this.issuer = issuer;
   }

   public void setThisUpdate(DERUTCTime thisUpdate) {
      V2TBSCertListGenerator var10000 = this;
      Time var2;
      var2 = new Time.<init>((DERObject)thisUpdate);
      var10000.thisUpdate = var2;
   }

   public void setNextUpdate(DERUTCTime nextUpdate) {
      V2TBSCertListGenerator var10000 = this;
      Time var2;
      var2 = new Time.<init>((DERObject)nextUpdate);
      var10000.nextUpdate = var2;
   }

   public void setThisUpdate(Time thisUpdate) {
      this.thisUpdate = thisUpdate;
   }

   public void setNextUpdate(Time nextUpdate) {
      this.nextUpdate = nextUpdate;
   }

   public void addCRLEntry(ASN1Sequence crlEntry) {
      if (this.crlentries == null) {
         Vector var2;
         var2 = new Vector.<init>();
         this.crlentries = var2;
      }

      this.crlentries.addElement(crlEntry);
   }

   public void addCRLEntry(DERInteger userCertificate, DERUTCTime revocationDate, int reason) {
      V2TBSCertListGenerator var10000 = this;
      Time var4;
      var4 = new Time.<init>((DERObject)revocationDate);
      var10000.addCRLEntry(userCertificate, var4, reason);
   }

   public void addCRLEntry(DERInteger userCertificate, Time revocationDate, int reason) {
      this.addCRLEntry(userCertificate, revocationDate, reason, (DERGeneralizedTime)null);
   }

   public void addCRLEntry(DERInteger userCertificate, Time revocationDate, int reason, DERGeneralizedTime invalidityDate) {
      Vector var5;
      var5 = new Vector.<init>();
      Vector var6;
      var6 = new Vector.<init>();
      IOException var12;
      IOException var14;
      boolean var15;
      Vector var10000;
      X509Extension var16;
      X509Extension var10002;
      boolean var10003;
      if (reason != 0) {
         label60: {
            var10000 = var6;
            Vector var10001 = var5;
            CRLReason var7;
            var7 = new CRLReason.<init>(reason);

            label57: {
               try {
                  var10001.addElement(X509Extensions.ReasonCode);
                  var16 = new X509Extension;
               } catch (IOException var11) {
                  var14 = var11;
                  var15 = false;
                  break label57;
               }

               var10002 = var16;
               var10003 = false;

               try {
                  var10002.<init>(var10003, new DEROctetString(var7.getEncoded()));
                  var10000.addElement(var16);
                  break label60;
               } catch (IOException var10) {
                  var14 = var10;
                  var15 = false;
               }
            }

            var12 = var14;
            throw new IllegalArgumentException("error encoding reason: " + var12);
         }
      }

      if (invalidityDate != null) {
         label61: {
            label59: {
               try {
                  var10000 = var6;
                  var5.addElement(X509Extensions.InvalidityDate);
                  var16 = new X509Extension;
               } catch (IOException var9) {
                  var14 = var9;
                  var15 = false;
                  break label59;
               }

               var10002 = var16;
               var10003 = false;

               try {
                  var10002.<init>(var10003, new DEROctetString(invalidityDate.getEncoded()));
                  var10000.addElement(var16);
                  break label61;
               } catch (IOException var8) {
                  var14 = var8;
                  var15 = false;
               }
            }

            var12 = var14;
            throw new IllegalArgumentException("error encoding invalidityDate: " + var12);
         }
      }

      if (var5.size() != 0) {
         V2TBSCertListGenerator var17 = this;
         X509Extensions var13;
         var13 = new X509Extensions.<init>(var5, var6);
         var17.addCRLEntry(userCertificate, revocationDate, var13);
      } else {
         this.addCRLEntry(userCertificate, revocationDate, (X509Extensions)null);
      }

   }

   public void addCRLEntry(DERInteger userCertificate, Time revocationDate, X509Extensions extensions) {
      ASN1EncodableVector var4;
      ASN1EncodableVector var10001 = var4 = new ASN1EncodableVector;
      var10001.<init>();
      var10001.add(userCertificate);
      var10001.add(revocationDate);
      if (extensions != null) {
         var4.add(extensions);
      }

      V2TBSCertListGenerator var10000 = this;
      DERSequence var5;
      var5 = new DERSequence.<init>(var4);
      var10000.addCRLEntry(var5);
   }

   public void setExtensions(X509Extensions extensions) {
      this.extensions = extensions;
   }

   public TBSCertList generateTBSCertList() {
      if (this.signature != null && this.issuer != null && this.thisUpdate != null) {
         ASN1EncodableVector var1;
         ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
         var1.<init>();
         var1.add(this.version);
         var1.add(this.signature);
         var1.add(this.issuer);
         var10001.add(this.thisUpdate);
         Time var2;
         if ((var2 = this.nextUpdate) != null) {
            var1.add(var2);
         }

         if (this.crlentries != null) {
            ASN1EncodableVector var6;
            var6 = new ASN1EncodableVector.<init>();
            Enumeration var3 = this.crlentries.elements();

            while(var3.hasMoreElements()) {
               var6.add((ASN1Sequence)var3.nextElement());
            }

            DERSequence var8;
            var8 = new DERSequence.<init>(var6);
            var1.add(var8);
         }

         X509Extensions var4;
         if ((var4 = this.extensions) != null) {
            DERTaggedObject var7;
            var7 = new DERTaggedObject.<init>(0, var4);
            var1.add(var7);
         }

         DERSequence var5;
         var5 = new DERSequence.<init>(var1);
         return new TBSCertList(var5);
      } else {
         throw new IllegalStateException("Not all mandatory fields set in V2 TBSCertList generator.");
      }
   }
}
